import Qt 4.7
import com.nokia.meego 1.0
import com.nokia.extras 1.0

import "UIConstants.js" as UI

Page {
    id:editSettingsScreen
    orientationLock: PageOrientation.LockPortrait
    tools: navigationToolbar
    anchors.margins: UI.HEADER_DEFAULT_TOP_SPACING_PORTRAIT

    property bool dhcpCheck: false

    ToolBarLayout {
        id: navigationToolbar
        ToolIcon { iconId: "toolbar-back";
            onClicked:{
                console.log("Back Button"); ipAddress.text = connectionScreen.ipVal; mask.text = connectionScreen.usbMaskVal; host.text = connectionScreen.hostIp
                pageStack.pop();
                rootWindow.pageStack.push("qrc:/qml_files/SdkConnectivityScreen.qml");
            }
        }
    }


    InfoBanner {
        id: infoBanner
        anchors.top: parent.top
        anchors.left: parent.left
        anchors.right: parent.right
        text: "Password Changed"
        z: 10
    }

    Flickable {
        id: flickableArea
        width: parent.width
        anchors.top: parent.top
        anchors.fill: parent
        contentWidth: pageContent.width
        contentHeight: pageContent.height

        Column {
            id: pageContent
            spacing: 20

            PageTitle {
                id: titleName
                width: flickableArea.width
                text: "Edit Settings"
                lineVisible: false
            }

            SectionHeader {
                text: "Network"
                width: flickableArea.width
            }

            Column {
                id:editSettingsColumn
                spacing:8

                Row {
                    width: flickableArea.width
                    Label {
                        id: ipAddressText
                        text: "IP Address"
                        anchors.verticalCenter: parent.verticalCenter
                        platformStyle: LabelStyle {
                            fontFamily: UI.FONT_FAMILY
                            fontPixelSize: UI.FONT_SLARGE
                        }
                    }

                    LabelValue {
                        id: ipAddressLabel
                        visible: connectionScreen.connectionType==="WLAN"
                        width:(flickableArea.width/1.5)
                        anchors.right: parent.right
                        text: connectionScreen.ipValWlan
                        color: "#797979"
                    }

                    TextField {
                        id:ipAddress
                        width:(flickableArea.width/1.5)
                        anchors.right: parent.right
                        visible: connectionScreen.connectionType!=="WLAN"
                        text:connectionScreen.connectionType[0]=="U"? connectionScreen.ipVal : connectionScreen.ipValWlan
                        inputMethodHints: Qt.ImhDigitsOnly
                        readOnly: connectionScreen.connectionType=="WLAN"? true: (dhcpCheckBox.checked)
                        platformStyle: TextFieldStyle {
                            textColor: ipAddress.readOnly ? UI.COLOR_DISABLED_FOREGROUND : UI.COLOR_FOREGROUND
                        }
                    }
                }
                Row {
                    width: flickableArea.width

                    Label {
                        id: maskText
                        text: "Mask"
                        anchors.verticalCenter: parent.verticalCenter
                        platformStyle: LabelStyle {
                            fontFamily: UI.FONT_FAMILY
                            fontPixelSize: UI.FONT_SLARGE
                        }
                    }

                    LabelValue {
                        id: maskLabel
                        visible: connectionScreen.connectionType==="WLAN"
                        width:(flickableArea.width/1.5)
                        anchors.right: parent.right
                        text: connectionScreen.wlanMaskVal
                        color: "#797979"
                    }

                    TextField {
                        id:mask
                        width:(flickableArea.width/1.5)
                        anchors.right: parent.right
                        text:connectionScreen.connectionType[0]=="U"? connectionScreen.usbMaskVal : connectionScreen.wlanMaskVal
                        inputMethodHints: Qt.ImhDigitsOnly
                        readOnly: connectionScreen.connectionType=="WLAN"? true: (dhcpCheckBox.checked)
                        visible: connectionScreen.connectionType!=="WLAN"
                        platformStyle: TextFieldStyle {
                            textColor: mask.readOnly ? UI.COLOR_DISABLED_FOREGROUND : UI.COLOR_FOREGROUND
                        }
                    }
                }
                Row {
                    width: flickableArea.width
                    visible: (connectionScreen.connectionType!=="WLAN")
                    Label {
                        id: hostText
                        text: "Host"
                        anchors.verticalCenter: parent.verticalCenter
                        platformStyle: LabelStyle {
                            fontFamily: UI.FONT_FAMILY
                            fontPixelSize: UI.FONT_SLARGE
                        }
                    }

                    LabelValue {
                        id: hostLabel
                        visible: connectionScreen.connectionType==="WLAN"
                        width:(flickableArea.width/1.5)
                        anchors.right: parent.right
                        text: connectionScreen.hostIp
                        color: "#797979"
                    }

                    TextField {
                        id:host
                        width:(flickableArea.width/1.5)
                        anchors.right: parent.right

                        text: connectionScreen.hostIp
                        readOnly: connectionScreen.connectionType=="WLAN"? true: (dhcpCheckBox.checked)
                        inputMethodHints: Qt.ImhDigitsOnly
                        platformStyle: TextFieldStyle {
                            textColor: host.readOnly ? UI.COLOR_DISABLED_FOREGROUND : UI.COLOR_FOREGROUND
                        }
                    }
                }
            }

            Row {
                id:dhcpRow
                spacing: 20
                width: flickableArea.width

                Label {
                    id: dhcpText
                    text: "Use DHCP"
                    anchors.verticalCenter: parent.verticalCenter
                    platformStyle: LabelStyle {
                        fontFamily: UI.FONT_FAMILY
                        fontPixelSize: UI.FONT_SLARGE
                    }
                }

                Switch {
                    id:dhcpCheckBox
                    anchors.right: parent.right
                    enabled: connectionScreen.connectionType!=="WLAN"
                    checked: connectionScreen.connectionType=="WLAN"? true: connectionScreen.dhcpSelectStatus
                }
            }

            Row {
                spacing: UI.HEADER_DEFAULT_TOP_SPACING_PORTRAIT*2
                width: flickableArea.width - UI.HEADER_DEFAULT_TOP_SPACING_PORTRAIT*2
                //Added push button to restore default settings
                Button {
                    id:defaultSettingsButton
                    text:"Reset"
                    width: parent.width/2
                    visible: connectionScreen.connectionType=="USB"?true:false
                    onClicked:{
                        console.log("Restore default settings");
                        ipAddress.text          =   "192.168.2.15"
                        ipAddressLabel.text = ipAddress.text
                        mask.text               =   "255.255.255.0"
                        maskLabel.text = mask.text
                        host.text               =   "192.168.2.14"
                        hostLabel.text = host.text
                        dhcpCheckBox.checked    =   true
                        infoBanner.text = "Network Settings restored!"
                        infoBanner.show();
                    }
                }

                Button {
                    id: buttonLeft; text: "Save"
                    width: parent.width/2
                    visible: connectionScreen.connectionType=="USB"?true:false
                    onClicked: {
                        if(dhcpCheckBox.checked == true)
                        {
                            dhcpCheck = true
                            console.log("Save Button- checkbox ON");
                            myWindow.configureUsb(ipAddress.text, mask.text, host.text, dhcpCheck )
                            pageStack.pop();
                            rootWindow.pageStack.push("qrc:/qml_files/WaitingScreen.qml");
                        }
                        else
                        {
                            dhcpCheck = false
                            console.log("Save Button- checkbox OFF");
                            myWindow.configureUsb(ipAddress.text, mask.text, host.text, dhcpCheck )
                            pageStack.pop();
                            rootWindow.pageStack.push("qrc:/qml_files/WaitingScreen.qml");
                        }
                        infoBanner.text = "Network Settings saved!"
                        infoBanner.show();
                    }
                }
            }

            SectionHeader {
                text: "Developer Account"
                width: flickableArea.width
            }

            Column {
                id:passwordColumn
                spacing: 20

                Row {
                    width: flickableArea.width
                    Label {
                        text: "Use custom password"
                        anchors.verticalCenter: parent.verticalCenter
                        platformStyle: LabelStyle {
                            fontFamily: UI.FONT_FAMILY
                            fontPixelSize: UI.FONT_SLARGE
                        }
                    }
                    Switch {
                        id: useCustomPassword
                        checked: connectionScreen.userPassword
                        anchors.right: parent.right
                        onCheckedChanged: {
                            connectionScreen.userPassword = useCustomPassword.checked
                        }
                    }
                }



                Row {
                    visible: useCustomPassword.checked
                    id:passwordFBRow
                    spacing: 20
                    width: flickableArea.width

                    Label {
                        id: passwordText
                        anchors.verticalCenter: parent.verticalCenter
                        text: "Password"
                        platformStyle: LabelStyle {
                            fontFamily: UI.FONT_FAMILY
                            fontPixelSize: UI.FONT_SLARGE
                        }
                    }
                    TextField {
                        id:passwordField
                        width:(flickableArea.width/1.5)
                        anchors.right: parent.right
                        focus: false
                        maximumLength: 15
                        echoMode: TextInput.Normal
                        text: connectionScreen.passwordVal

                        property bool savePassword : false

                        Keys.onEnterPressed: {
                            closeSoftwareInputPanel();
                            doSavePassword();
                            focus = false;
                        }

                        Keys.onReturnPressed: {
                            closeSoftwareInputPanel();
                            doSavePassword();
                            focus = false;
                        }

                        function doSavePassword() {
                            connectionScreen.passwordVal = passwordField.text;
                            autoPasswordLabel.text = passwordField.text;
                            connectionScreen.userPassword = true;
                            myWindow.setUserPassword(passwordField.text);
                            savePassword = false;
                            infoBanner.text = "Password Changed!"
                            infoBanner.show();
                        }

                        onTextChanged:  { // we set the password here because of the virtual keyboard
                            if (savePassword) {
                                doSavePassword();
                            }
                        }
                        onActiveFocusChanged: {
                            if (passwordField.focus==false) {
                                savePassword = true;
                            }
                        }

                    }
                }

                Row {
                    visible: !useCustomPassword.checked
                    id: autoPasswordFBRow
                    spacing: 20
                    width: flickableArea.width

                    Label {
                        id: autoPasswordText
                        anchors.verticalCenter: parent.verticalCenter
                        text: "Password"
                        platformStyle: LabelStyle {
                            fontFamily: UI.FONT_FAMILY
                            fontPixelSize: UI.FONT_SLARGE
                        }
                    }
                    LabelValue {
                        id:autoPasswordLabel
                        width:(flickableArea.width/1.5)
                        anchors.right: parent.right
                        color: "#797979"
                        text: connectionScreen.passwordVal

                    }
                }

                Button {
                    visible: !useCustomPassword.checked
                    id:reset
                    text: "Generate Password"
                    anchors.right: parent.right
                    width:(flickableArea.width/1.5)
                    onClicked: {
                        console.log("on Reset Passwd .."+passwordField.text)
                        connectionScreen.userPassword = false

                        myWindow.newPassword();
                        infoBanner.text = "Password Generated!"
                        infoBanner.show();
                    }
                }
            }
        }
    }




}
