import Qt 4.7
import com.nokia.meego 1.0
import com.nokia.extras 1.0

import "UIConstants.js" as UI

Page {
    id:vncServerScreen
    orientationLock: PageOrientation.LockPortrait
    tools: navigationToolbar

    anchors.margins: UI.HEADER_DEFAULT_TOP_SPACING_PORTRAIT

    InfoBanner {
         id: banner
         z:1
         timerShowTime: 10000

         Connections {
             target: myWindow
             onFileSaved:{
                 console.log("QML - onfileSaved: "+myWindow.fileName)
                 banner.text = "File saved at: "+myWindow.fileName
                 banner.show();
             }
         }
     }

    PageTitle {
        id: titleName
        anchors.top: parent.top
        text: "VNC"
    }

    ToolBarLayout {
        id: navigationToolbar
        ToolIcon { iconId: "toolbar-back";
            onClicked:{
                console.log("Back Button");
                if(vncSwitch.checked)
                {
                    connectionScreen.vncSwitchStatus = true
                    connectionScreen.previousVncStatus = true
                    connectionScreen.vncTempOutput = vncOutput.text
                }
                else
                {
                    connectionScreen.vncSwitchStatus = false
                    connectionScreen.vncTempOutput = ""
                    connectionScreen.previousVncStatus = false
                }

                pageStack.pop();
            }
        }
    }

    Column {
        spacing: 20
        anchors.topMargin: UI.HEADER_DEFAULT_TOP_SPACING_PORTRAIT
        anchors.top: titleName.bottom
        anchors.bottom: parent.bottom
        anchors.left: parent.left
        anchors.right: parent.right


        Row {
            id:vncRow
            width: parent.width

            Label {
                id:vncServerLabel
                text: "Enabled"
                anchors.verticalCenter: parent.verticalCenter
                platformStyle: LabelStyle {
                    fontFamily: UI.FONT_FAMILY
                    fontPixelSize: UI.FONT_SLARGE
                }
                font.bold: true
            }
            Switch {
                id:vncSwitch
                anchors.right: parent.right
                checked: connectionScreen.vncSwitchStatus //false
                onCheckedChanged: {
                    console.log("vnc switch status = ",vncSwitch.checked)
                    if(vncSwitch.checked && connectionScreen.previousVncStatus == false)
                    {
                        console.log("connectionScreen.previousVncStatus = ",connectionScreen.previousVncStatus)
                        if(connectionScreen.connectionType=="USB")
                        {
                            myWindow.vncProcessStart(connectionScreen.ipVal)
                        }
                        else
                        {
                            myWindow.vncProcessStart(connectionScreen.ipValWlan)
                        }
                    }
                    else if(!vncSwitch.checked)
                    {
                        myWindow.vncProcessStop()
                        connectionScreen.vncSwitchStatus = false
                        connectionScreen.previousVncStatus = false

                    }
                }
            }
        }

        /*workaround for textArea START*/

        Rectangle {
            id:vncOutputRect
            radius: 20
            width: parent.width
            height: 440

            Flickable {
                id: flickable1
                anchors.fill: parent

                contentWidth: vncOutput.paintedWidth
                contentHeight: vncOutput.paintedHeight
                clip: true

                function ensureVisible(r)
                {
                    if (contentX >= r.x)
                        contentX = r.x;
                    else if (contentX+width <= r.x+r.width)
                        contentX = r.x+r.width-width;

                    if (contentY >= r.y)
                        contentY = r.y;
                    else if (contentY+height <= r.y+r.height)
                    {
                        contentY = r.y+r.height-height;
                    }

                }

                TextEdit {
                    id: vncOutput
                    width: flickable1.width
                    height: flickable1.height
                    text: connectionScreen.vncTempOutput
                    cursorVisible: false
                    readOnly: true
                    font.pixelSize: 16
                    focus: false
                    anchors.leftMargin: 30
                    wrapMode: TextEdit.NoWrap
                    onCursorRectangleChanged: flickable1.ensureVisible(vncOutput.cursorRectangle)

                    Connections {
                        target: vncProcess
                        onLogDataChanged:{

                            vncOutput.text += vncProcess.logData;
                            vncOutput.cursorPosition = vncOutput.text.length;


                        }
                    }

                }

            }
        }

        Row {
            id:saveClearButtonRow
            width: parent.width

            Button {
                id:saveButton
                text: "Save"
                width:implicitWidth/2
                enabled: vncOutput.text == ""? false : true
                onClicked: { console.log("Save Clicked")
                    myWindow.vncSaveToFile(vncOutput.text);
                }
            }
            Button {
                id:clearButton
                anchors.right: parent.right
                text: "Clear"
                width:implicitWidth/2
                enabled:vncOutput.text == "" ? false : true
                onClicked: { console.log("Clear Clicked")
                    vncOutput.text = ""
                }
            }

        }
    }
}
